==> open-autonomy-0.10.11.post1.tar.gz: open-autonomy-0.10.11.post1/SECURITY.md <==
# Security Policy

This document outlines security procedures and general policies for the `open-autonomy` project.

## Supported Versions

The following table shows which versions of `open-autonomy` are currently being supported with security updates.

| Version   | Supported          |
| --------- | ------------------ |
| `0.10.11.post1`   | :white_check_mark: |
| `< 0.10.11.post1` | :x:                |

## Reporting a Vulnerability

The `open-autonomy` team and community take all security bugs in `open-autonomy` seriously. Thank you for improving the security of `open-autonomy`. We appreciate your efforts and responsible disclosure and will make every effort to acknowledge your contributions.

Report security bugs by emailing `info@valory.xyz`.

The lead maintainer will acknowledge your email within 48 hours, and will send a more detailed response within 48 hours indicating the next steps in handling your report. After the initial reply to your report, the security team will endeavour to keep you informed of the progress towards a fix and full announcement, and may ask for additional information or guidance.

Report security bugs in third-party modules to the person or team maintaining the module.

## Disclosure Policy

When the security team receives a security bug report, they will assign it to a primary handler. This person will coordinate the fix and release process, involving the following steps:

- Confirm the problem and determine the affected versions.
- Audit code to find any potential similar problems.
- Prepare fixes for all releases still under maintenance. These fixes will be released as fast as possible to PyPI.

## Comments on this Policy

If you have suggestions on how this process could be improved please submit a pull request.

==> open-autonomy-0.11.0.tar.gz: open-autonomy-0.11.0/SECURITY.md <==
# Security Policy

This document outlines security procedures and general policies for the `open-autonomy` project.

## Supported Versions

The following table shows which versions of `open-autonomy` are currently being supported with security updates.

| Version   | Supported          |
| --------- | ------------------ |
| `0.11.0`   | :white_check_mark: |
| `< 0.11.x` | :x:                |

## Reporting a Vulnerability

The `open-autonomy` team and community take all security bugs in `open-autonomy` seriously. Thank you for improving the security of `open-autonomy`. We appreciate your efforts and responsible disclosure and will make every effort to acknowledge your contributions.

Report security bugs by emailing `info@valory.xyz`.

The lead maintainer will acknowledge your email within 48 hours, and will send a more detailed response within 48 hours indicating the next steps in handling your report. After the initial reply to your report, the security team will endeavour to keep you informed of the progress towards a fix and full announcement, and may ask for additional information or guidance.

Report security bugs in third-party modules to the person or team maintaining the module.

## Disclosure Policy

When the security team receives a security bug report, they will assign it to a primary handler. This person will coordinate the fix and release process, involving the following steps:

- Confirm the problem and determine the affected versions.
- Audit code to find any potential similar problems.
- Prepare fixes for all releases still under maintenance. These fixes will be released as fast as possible to PyPI.

## Comments on this Policy

If you have suggestions on how this process could be improved please submit a pull request.
